@@ -2,7 +2,10 @@ fscores.r <-
 function (betas, X, method) {
     logf.z <- function (z, y, betas) {
         pr <- probs(c(betas %*% c(1, z)))
-        -sum(dbinom(y, 1, pr, log = TRUE), na.rm = TRUE) - dnorm(z, log = TRUE)
+        if (prior)
+            -sum(dbinom(y, 1, pr, log = TRUE), na.rm = TRUE) - dnorm(z, log = TRUE)
+        else
+            -sum(dbinom(y, 1, pr, log = TRUE), na.rm = TRUE)
     }
     fscore <- function (logf.z, y, betas) {
         opt <- optim(0, fn = logf.z, method = "BFGS", hessian = TRUE, y = y, betas = betas)
@@ -61,6 +64,8 @@ function (betas, X, method) {
         hes.av <- hes.av + (1 + 1/B) * SV
         res$z1 <- scores.av
         res$se.z1 <- sqrt(hes.av)
+        attr(res, "zvalues.MI") <- scores.B
+        attr(res, "var.zvalues.MI") <- hes.B
     }
     res
 }
